==> open5gs_2.4.9.tar.xz: BUILD/README.md <==
<h1 align="center">Open5GS</h1>

If you find Open5GS useful for work, please consider supporting this Open Source project by [Becoming a sponsor](https://github.com/sponsors/acetcom). To manage the funding transactions transparently, you can donate through [OpenCollective](https://opencollective.com/open5gs).

<h3 align="center">Platinum Sponsors</h3>
<table align="center">
  <tbody>
    <tr>
      <td align="center" valign="middle">
  <a href="https://teletresearch.com/" target="_blank">
    <img width="400px" src="https://open5gs.org/assets/img/Telet-logo-v2.png">
  </a>
      </td>
    </tr>
  </tbody>
</table>

<h3 align="center">Gold Sponsors</h3>
<table align="center">
  <tbody>
    <tr>
      <td align="center" valign="middle">
  <a href="http://wavemobile.com/" target="_blank">
    <img width="222px" src="https://open5gs.org/assets/img/Wavemobile-Logo-Mark-RGB.png">
  </a>
      </td>
    </tr>
  </tbody>
</table>

<h3 align="center">Silver Sponsors</h3>
<table align="center">
  <tbody>
    <tr>
      <td align="center" valign="middle" width="222px">
        <a href="https://nextepc.com/" target="_blank">
          <img src="https://open5gs.org/assets/img/nextepc_logo.jpg">
        </a>
      </td>
      <td align="center" valign="middle" width="222px">
        <a href="https://www.wearetriple.com/" target="_blank">
          <img src="https://open5gs.org/assets/img/triple_logo.png">
        </a>
      </td>
      <td align="center" valign="middle" width="222px">
        <a href="https://sdr.eee.strath.ac.uk/" target="_blank">
          <img src="https://open5gs.org/assets/img/strath.png">
        </a>
      </td>
    </tr>
    <tr>
      <td align="center" valign="middle" width="222px">
        <a href="https://skylarkwireless.com/" target="_blank">
          <img src="https://open5gs.org/assets/img/SkylarkWireless-420x78-Web2-R.png">
        </a>
      </td>
      <td align="center" valign="middle" width="222px">
        <a href="https://sysmocom.de/" target="_blank">
          <img src="https://open5gs.org/assets/img/sysmocom-logo-only.png">
        </a>
      </td>
      <td align="center" valign="middle" width="222px">
        <a href="https://www.p1sec.com/" target="_blank">
          <img src="https://open5gs.org/assets/img/2021-logo-P1.svg">
        </a>
      </td>
    </tr>
    <tr>
      <td align="center" valign="middle" width="222px">
        <a href="https://www.ng-voice.com/" target="_blank">
          <img src="https://open5gs.org/assets/img/ng-voice-logo_color.png">
        </a>
      </td>
      <td align="center" valign="middle" width="222px">
        <a href="http://www.bristol.ac.uk/engineering/research/smart/" target="_blank">
          <img src="https://open5gs.org/assets/img/smart-internet-lab.png">
        </a>
      </td>
    </tr>
  </tbody>
</table>

## Documentation

If you don't understand something about Open5GS, the [https://open5gs.org/open5gs/docs/](https://open5gs.org/open5gs/docs/) is a great place to look for answers.

## Community

- Problem with Open5GS can be filed as [issues](https://github.com/open5gs/open5gs/issues) in this repository.
- Other topics related to this project are happening on the [discussions](https://github.com/open5gs/open5gs/discussions).
- Voice and text chat are available in Open5GS's [Discord](https://discordapp.com/) workspace. Use [this link](https://discord.gg/GreNkuc) to get started.

## Contributing

If you're contributing through a pull request to Open5GS project on GitHub, please read the [Contributor License Agreement](https://open5gs.org/open5gs/cla/) in advance.

## License

- Open5GS Open Source files are made available under the terms of the GNU Affero General Public License ([GNU AGPL v3.0](https://www.gnu.org/licenses/agpl-3.0.html)).
- [Commercial licenses](https://open5gs.org/open5gs/support/) are also available from [NextEPC, Inc.](https://nextepc.com)

==> open5gs_2.4.11.tar.xz: BUILD/README.md <==
<p align="center"><a href="https://open5gs.org" target="_blank" rel="noopener noreferrer"><img width="100" src="https://open5gs.org/assets/img/open5gs-logo-only.png" alt="Open5GS logo"></a></p>

## Getting Started

If you don't understand something about Open5GS, the [https://open5gs.org/open5gs/docs/](https://open5gs.org/open5gs/docs/) is a great place to look for answers.

## Sponsors

If you find Open5GS useful for work, please consider supporting this Open Source project by [Becoming a sponsor](https://github.com/sponsors/acetcom). To manage the funding transactions transparently, you can donate through [OpenCollective](https://opencollective.com/open5gs).

<p align="center">
  <a target="_blank" href="https://open5gs.org/#sponsors">
      <img alt="sponsors" src="https://open5gs.org/assets/img/sponsors.svg">
  </a>
</p>

## Community

- Problem with Open5GS can be filed as [issues](https://github.com/open5gs/open5gs/issues) in this repository.
- Other topics related to this project are happening on the [discussions](https://github.com/open5gs/open5gs/discussions).
- Voice and text chat are available in Open5GS's [Discord](https://discordapp.com/) workspace. Use [this link](https://discord.gg/GreNkuc) to get started.

## Contributing

If you're contributing through a pull request to Open5GS project on GitHub, please read the [Contributor License Agreement](https://open5gs.org/open5gs/cla/) in advance.

## License

- Open5GS Open Source files are made available under the terms of the GNU Affero General Public License ([GNU AGPL v3.0](https://www.gnu.org/licenses/agpl-3.0.html)).
- [Commercial licenses](https://open5gs.org/open5gs/support/) are also available from [NeoPlane](https://neoplane.io/)
